/*************************************************************************
TuXBuZZ - bY DoC#include
server.h
*************************************************************************/

#ifndef SERVER_H
#define SERVER_H

#include <stdio.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <sys/stat.h>
#include <fcntl.h>
#ifdef LINUX
  #include <resolv.h> /* exclusivo do linux */
#endif
#include <string.h>
#include <errno.h>
#include <unistd.h>
#include <signal.h>

#include "tuxbuzzpackage.h"
#include "messages.h"
#include "zombiekiller.h"

#define PORT 8081   /*porta padrao do servidor */


#define VERSION "v0.0.2b"


/* fim de server.h */

          





#endif
